@@ -98,7 +98,15 @@ def make_th(table: Table, data: Dataset, context: TableContext, column: Column)
             del args["sort_by1"]
 
         sort_url = url(path=context.path, args=args, search=context.search, **sort_args)
-        a = Node("a", attributes={"href": sort_url, "data-hx-get": sort_url, "data-hx-target": context.hx_target})
+        a = Node(
+            "a",
+            attributes={
+                "href": sort_url,
+                "data-hx-get": sort_url,
+                "data-hx-target": context.hx_target,
+                "data-hx-select": context.hx_target,
+            },
+        )
         th += a
         target = a
     target += column.title
@@ -187,7 +195,13 @@ def make_pagination_li(
         a_attributes["aria-disabled"] = True
     else:
         a_attributes.update(
-            {"href": pagination_url, "data-hx-get": pagination_url, "data-hx-target": target, "aria-label": aria_label}
+            {
+                "href": pagination_url,
+                "data-hx-get": pagination_url,
+                "data-hx-target": target,
+                "data-hx-select": target,
+                "aria-label": aria_label,
+            }
         )
     li = Node("li", attributes=li_attributes)
     li += Node("a", text, attributes=a_attributes,)
